<?php

/**
 * Project:     SmartyPaginate: Pagination for the Smarty Template Engine
 * File:        function.paginate_middle.php
 * Author:      Monte Ohrt <monte@ispi.net>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * @link http://www.phpinsider.com/php/code/SmartyPaginate/
 * @copyright 2001-2004 ispi of Lincoln, Inc.
 * @author Monte Ohrt <monte@ispi.net>
 * @package SmartyPaginate
 * @version 1.2
 */

function smarty_function_paginate_middle2($params, &$smarty) {

    $_id = isset($params['id']) ? $params['id'] : 'default';
    
    $_prefix = isset($params['prefix']) ? $params['prefix'] : '[';
    $_suffix = isset($params['suffix']) ? $params['suffix'] : ']';
    
    if (!class_exists('SmartyPaginate')) {
        $smarty->trigger_error("paginate_middle: missing SmartyPaginate class");
        return;
    }
    if (!isset($_SESSION['SmartyPaginate'])) {
        $smarty->trigger_error("paginate_middle: SmartyPaginate is not initialized, use connect() first");
        return;        
    }
    if (!isset($_SESSION['SmartyPaginate'][$_id]['item_total'])) {
        $smarty->trigger_error("paginate_middle: total was not set");
        return;        
    }
    
    $_url = $_SESSION['SmartyPaginate'][$_id]['url'];
    
    $_total = SmartyPaginate::getTotal($_id);
    $_curr_item = SmartyPaginate::getCurrentItem($_id);
    $_limit = SmartyPaginate::getLimit($_id);
    
    $_item = 1;
    $_page = 1;
    
    while($_item <= $_total) {
        if($params['format'] == 'page') {
            $_text = $_prefix . $_page . $_suffix;            
        } else {
            $_text = $_prefix . $_item . '-';
            $_text .= ($_item + $_limit - 1 <= $_total) ? $_item + $_limit - 1 : $_total;
            $_text .= $_suffix;
        }
        if($_item != $_curr_item) {
            $_this_url = $_url;
            //$_this_url .= (strpos($_url, '?') === false) ? '?' : '&';
            $_this_url .=  $_item;
            $_ret .= '<a href="' . $_this_url . '">' . $_text . '</a>';
        } else {
            $_ret .= $_text;
        }
        $_item += $_limit;
        $_page++;
    }
    
    return $_ret;
    
}

?>
